==> apache-camel-2.17.7-src.zip: apache-camel-2.17.7/components/camel-spark-rest/src/main/java/org/apache/camel/component/sparkrest/SparkMessage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.sparkrest;

import org.apache.camel.impl.DefaultMessage;
import spark.Request;
import spark.Response;

/**
 * Spark based {@link org.apache.camel.Message}.
 * <p/>
 * This implementation allows direct access to the Spark {@link Request} using
 * the {@link #getRequest()} method.
 */
public class SparkMessage extends DefaultMessage {

    private final transient Request request;
    private final transient Response response;

    public SparkMessage(Request request, Response response) {
        this.request = request;
        this.response = response;
    }

    public Request getRequest() {
        return request;
    }

    public Response getResponse() {
        return response;
    }

    @Override
    public DefaultMessage newInstance() {
        return new SparkMessage(request, response);
    }
}

==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-spark-rest/src/main/java/org/apache/camel/component/sparkrest/SparkMessage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.sparkrest;

import org.apache.camel.CamelContext;
import org.apache.camel.impl.DefaultMessage;
import spark.Request;
import spark.Response;

/**
 * Spark based {@link org.apache.camel.Message}.
 * <p/>
 * This implementation allows direct access to the Spark {@link Request} using
 * the {@link #getRequest()} method.
 */
public class SparkMessage extends DefaultMessage {

    private final transient Request request;
    private final transient Response response;

    public SparkMessage(CamelContext camelContext, Request request, Response response) {
        super(camelContext);
        this.request = request;
        this.response = response;
    }

    public Request getRequest() {
        return request;
    }

    public Response getResponse() {
        return response;
    }

    @Override
    public DefaultMessage newInstance() {
        return new SparkMessage(getCamelContext(), request, response);
    }
}
